Documentation
¶
Overview ¶
Package parser parses snapchat chat history from a json file to a struct.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Content ¶
type Content struct {
From string
MediaType string `json:"Media Type"`
Created string
Content string `json:",omitempty"`
ConversationTitle string `json:"Conversation Title"`
IsSender bool `json:"isSender"`
CreatedMicrosecond int64 `json:"Created(microseconds)"`
}
Content contains the fields in the chat history json file
Click to show internal directories.
Click to hide internal directories.